@@ -10,11 +10,11 @@
   as published by the Free Software Foundation.
   
   ********************************************
-  Coppermine version: 1.4.23
+  Coppermine version: 1.4.25
   $HeadURL: https://coppermine.svn.sourceforge.net/svnroot/coppermine/trunk/cpg1.4.x/editOnePic.php $
-  $Revision: 5891 $
+  $Revision: 5997 $
   $Author: gaugau $
-  $Date: 2009-05-01 23:44:32 +0200 (Fr, 01 Mai 2009) $
+  $Date: 2009-05-26 08:43:24 +0200 (Di, 26 Mai 2009) $
 **********************************************/
 
 define('IN_COPPERMINE', true);
@@ -265,7 +265,7 @@ if (!is_movie($CURRENT_PIC['filename'])) {
 
 if (defined('UPLOAD_APPROVAL_MODE')) {
         if ($CURRENT_PIC['owner_name']){
-                $pic_info .= ' - <a href ="profile.php?uid='.$CURRENT_PIC['owner_id'].'" target="_blank">'.$CURRENT_PIC['owner_name'].'</a>';
+                $pic_info .= ' - <a href ="profile.php?uid='.$CURRENT_PIC['owner_id'].'">'.$CURRENT_PIC['owner_name'].'</a>';
         }
 }
 
