@@ -10,11 +10,11 @@
   as published by the Free Software Foundation.
   
   ********************************************
-  Coppermine version: 1.4.23
+  Coppermine version: 1.4.25
   $HeadURL: https://coppermine.svn.sourceforge.net/svnroot/coppermine/trunk/cpg1.4.x/themes/hardwired/theme.php $
-  $Revision: 5891 $
+  $Revision: 5997 $
   $Author: gaugau $
-  $Date: 2009-05-01 23:44:32 +0200 (Fr, 01 Mai 2009) $
+  $Date: 2009-05-26 08:43:24 +0200 (Di, 26 Mai 2009) $
 **********************************************/
 
 define('THEME_HAS_RATING_GRAPHICS', 1);
@@ -207,7 +207,7 @@ $template_gallery_admin_menu = <<<EOT
                                 <td class="admin_menu"><a href="util.php" title="{UTIL_TITLE}">{UTIL_LNK}</a></td>
                                 <td class="admin_menu"><a href="profile.php?op=edit_profile" title="{MY_PROF_TITLE}">{MY_PROF_LNK}</a></td>
 <!-- BEGIN documentation -->
-                                <td class="admin_menu"><a href="{DOCUMENTATION_HREF}" title="{DOCUMENTATION_TITLE}" target="cpg_documentation">{DOCUMENTATION_LNK}</a></td>
+                                <td class="admin_menu"><a href="{DOCUMENTATION_HREF}" title="{DOCUMENTATION_TITLE}">{DOCUMENTATION_LNK}</a></td>
 <!-- END documentation -->
                         </tr>
                 </table>
